@@ -4,6 +4,6 @@
 ###############################################################################
 
 
-setMethod("toJSON", "NULL",
+setMethod("asJSON", "NULL",
 	function(x, ...) {return("{}");}
 );
